==> nextcloud-27.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/uk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Зазначений оператор недійсний",
    "The given regular expression is invalid" : "Зазначений регулярний вираз недійсний",
    "The given file size is invalid" : "Зазначений розмір файлу недійсний",
    "The given tag id is invalid" : "Зазначений ідентифікатор мітки недійсний",
    "The given IP range is invalid" : "Зазначений діапазон IP-адрес недійсний",
    "The given IP range is not valid for IPv4" : "Зазначений діапазон IP-адрес недійсний для IPv4",
    "The given IP range is not valid for IPv6" : "Зазначений діапазон IP-адрес недійсний для IPv6",
    "The given time span is invalid" : "Зазначений часовий проміжок недійсний",
    "The given start time is invalid" : "Зазначений час початку недійсний",
    "The given end time is invalid" : "Зазначений час завершення недійсний",
    "The given group does not exist" : "Зазначена група не існує",
    "File" : "Файл",
    "File created" : "Файл створено",
    "File updated" : "Файл оновлено",
    "File renamed" : "Файл перейменовано",
    "File deleted" : "Файл вилучено",
    "File accessed" : "Отримано доступ до файлу",
    "File copied" : "Файл скопійовано",
    "Tag assigned" : "Призначено мітку",
    "Someone" : "Хтось",
    "%s created %s" : "%s створив(-ла) %s",
    "%s modified %s" : "%s змінив(-ла) %s",
    "%s deleted %s" : "%s вилучив(-ла) %s",
    "%s accessed %s" : "%s отримав(-ла) доступ до %s",
    "%s renamed %s" : "%s перейменував(-ла) %s",
    "%s copied %s" : "%s скопіював(-ла) %s",
    "%s assigned %s to %s" : "%s призначив(-ла) мітку%s файлу %s",
    "Operation #%s does not exist" : "Операція №%s не існує",
    "Entity %s does not exist" : "Об'єкт %s відсутній ",
    "Entity %s is invalid" : "Об'єкт %s не дійсний",
    "No events are chosen." : "Не вибрано жодної події.",
    "Entity %s has no event %s" : "Об'єкт %s не має події %s",
    "Operation %s does not exist" : "Операція %s не існує",
    "Operation %s is invalid" : "Операція %s недійсна",
    "At least one check needs to be provided" : "Потрібно визначити принаймні одну перевірку",
    "The provided operation data is too long" : "Надано задовгі дані для операції",
    "Invalid check provided" : "Зазначено недійсну перевірку",
    "Check %s does not exist" : "Перевірка %s не існує",
    "Check %s is invalid" : "Перевірка %s недійсна",
    "Check %s is not allowed with this entity" : "Перевірку %s не дозволено для цієї сутності",
    "The provided check value is too long" : "Зазначено задовге перевірочне значення",
    "Check #%s does not exist" : "Перевірка №%s не існує",
    "Check %s is invalid or does not exist" : "Перевірка %s недійсна або не існує",
    "Flow" : "Процеси",
    "Nextcloud workflow engine" : "Керування робочими процесами у Nextcloud",
    "Select a filter" : "Виберіть фільтр",
    "Select a comparator" : "Виберіть засіб для порівняння",
    "Remove filter" : "Вилучити фільтр",
    "Select a file type" : "Виберіть тип файлу",
    "e.g. httpd/unix-directory" : "напр., httpd/unix-directory",
    "Folder" : "Каталог",
    "Images" : "Зображення",
    "Office documents" : "Офісні документи",
    "PDF documents" : "Документи PDF",
    "Custom MIME type" : "Власний тип MIME",
    "Custom mimetype" : "Власний mimetype",
    "Please enter a valid time span" : "Зазначте дійсний часовий проміжок",
    "Select a request URL" : "Виберіть URL для запиту",
    "Files WebDAV" : "Файли WebDAV",
    "Custom URL" : "Власний URL",
    "Select a user agent" : "Виберіть user agent",
    "Android client" : "Клієнт Android",
    "iOS client" : "iOS клієнт",
    "Desktop client" : "Клієнт для ПК",
    "Thunderbird & Outlook addons" : "Доповнення Thunderbird та Outlook",
    "Custom user agent" : "Власний user agent",
    "Select a trigger" : "Виберіть умову початку виконання",
    "At least one event must be selected" : "Потрібно вибрати принаймні одну подію",
    "Add new flow" : "Додати новий процес",
    "When" : "Коли",
    "and" : "та",
    "Add a new filter" : "Додати новий фільтр",
    "Cancel" : "Скасувати",
    "Delete" : "Вилучити",
    "The configuration is invalid" : "Налаштування не дійсне",
    "Active" : "Активно",
    "Save" : "Зберегти",
    "Available flows" : "Процеси",
    "For details on how to write your own flow, check out the development documentation." : "Перегляньте документацію для розробника, щоби дізнатися, як додати власні процеси.",
    "More flows" : "Більше процесів",
    "Browse the App Store" : "Перейти до App Store",
    "Show less" : "Показувати менше",
    "Show more" : "Показати більше",
    "Configured flows" : "Налаштовані процеси",
    "Your flows" : "Ваші процеси",
    "matches" : "містить",
    "does not match" : "не містить",
    "is" : "є",
    "is not" : "не",
    "File name" : "Ім'я файлу",
    "File MIME type" : "Тип MIME файлу",
    "File size (upload)" : "Розмір файлу (завантаження)",
    "less" : "менше",
    "less or equals" : "менше або дорівнює",
    "greater or equals" : "більше або дорівнює",
    "greater" : "більше",
    "Request remote address" : "Запит віддаленої адреси",
    "matches IPv4" : "відповідає IPv4",
    "does not match IPv4" : "не відповідає IPv4",
    "matches IPv6" : "відповідає IPv6",
    "does not match IPv6" : "не відповідає IPv6",
    "File system tag" : "Мітка файлової системи",
    "is tagged with" : "позначено міткою",
    "is not tagged with" : "не позначено мітками",
    "Request URL" : "URL запиту",
    "Request time" : "Час запиту",
    "between" : "між",
    "not between" : "не між",
    "Request user agent" : "Запит агента користувача",
    "User group membership" : "Участь користувача в групі",
    "is member of" : "є учасником",
    "is not member of" : "не є учасником",
    "Predefined URLs" : "Попередньо визначені URL-адреси",
    "Others" : "Інші"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/uk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Зазначений оператор недійсний",
    "The given regular expression is invalid" : "Зазначений регулярний вираз недійсний",
    "The given file size is invalid" : "Зазначений розмір файлу недійсний",
    "The given tag id is invalid" : "Зазначений ідентифікатор мітки недійсний",
    "The given IP range is invalid" : "Зазначений діапазон IP-адрес недійсний",
    "The given IP range is not valid for IPv4" : "Зазначений діапазон IP-адрес недійсний для IPv4",
    "The given IP range is not valid for IPv6" : "Зазначений діапазон IP-адрес недійсний для IPv6",
    "The given time span is invalid" : "Зазначений часовий проміжок недійсний",
    "The given start time is invalid" : "Зазначений час початку недійсний",
    "The given end time is invalid" : "Зазначений час завершення недійсний",
    "The given group does not exist" : "Зазначена група не існує",
    "File" : "Файл",
    "File created" : "Файл створено",
    "File updated" : "Файл оновлено",
    "File renamed" : "Файл перейменовано",
    "File deleted" : "Файл вилучено",
    "File accessed" : "Отримано доступ до файлу",
    "File copied" : "Файл скопійовано",
    "Tag assigned" : "Призначено мітку",
    "Someone" : "Хтось",
    "%s created %s" : "%s створив(-ла) %s",
    "%s modified %s" : "%s змінив(-ла) %s",
    "%s deleted %s" : "%s вилучив(-ла) %s",
    "%s accessed %s" : "%s отримав(-ла) доступ до %s",
    "%s renamed %s" : "%s перейменував(-ла) %s",
    "%s copied %s" : "%s скопіював(-ла) %s",
    "%s assigned %s to %s" : "%s призначив(-ла) мітку%s файлу %s",
    "Operation #%s does not exist" : "Операція №%s не існує",
    "Entity %s does not exist" : "Об'єкт %s відсутній ",
    "Entity %s is invalid" : "Об'єкт %s не дійсний",
    "No events are chosen." : "Не вибрано жодної події.",
    "Entity %s has no event %s" : "Об'єкт %s не має події %s",
    "Operation %s does not exist" : "Операція %s не існує",
    "Operation %s is invalid" : "Операція %s недійсна",
    "At least one check needs to be provided" : "Потрібно визначити принаймні одну перевірку",
    "The provided operation data is too long" : "Надано задовгі дані для операції",
    "Invalid check provided" : "Зазначено недійсну перевірку",
    "Check %s does not exist" : "Перевірка %s не існує",
    "Check %s is invalid" : "Перевірка %s недійсна",
    "Check %s is not allowed with this entity" : "Перевірку %s не дозволено для цієї сутності",
    "The provided check value is too long" : "Зазначено задовге перевірочне значення",
    "Check #%s does not exist" : "Перевірка №%s не існує",
    "Check %s is invalid or does not exist" : "Перевірка %s недійсна або не існує",
    "Flow" : "Процеси",
    "Nextcloud workflow engine" : "Керування робочими процесами у Nextcloud",
    "Select a filter" : "Виберіть фільтр",
    "Select a comparator" : "Виберіть засіб для порівняння",
    "Remove filter" : "Вилучити фільтр",
    "Select a file type" : "Виберіть тип файлу",
    "e.g. httpd/unix-directory" : "напр., httpd/unix-directory",
    "Folder" : "Каталог",
    "Images" : "Зображення",
    "Office documents" : "Офісні документи",
    "PDF documents" : "Документи PDF",
    "Custom MIME type" : "Власний тип MIME",
    "Custom mimetype" : "Власний mimetype",
    "Please enter a valid time span" : "Зазначте дійсний часовий проміжок",
    "Select a request URL" : "Виберіть URL для запиту",
    "Files WebDAV" : "Файли WebDAV",
    "Custom URL" : "Власний URL",
    "Select a user agent" : "Виберіть user agent",
    "Android client" : "Клієнт Android",
    "iOS client" : "iOS клієнт",
    "Desktop client" : "Клієнт для ПК",
    "Thunderbird & Outlook addons" : "Доповнення Thunderbird та Outlook",
    "Custom user agent" : "Власний user agent",
    "Select groups" : "Виберіть групи",
    "Groups" : "Групи",
    "Select a trigger" : "Виберіть умову початку виконання",
    "At least one event must be selected" : "Потрібно вибрати принаймні одну подію",
    "Add new flow" : "Додати новий процес",
    "When" : "Коли",
    "and" : "та",
    "Add a new filter" : "Додати новий фільтр",
    "Cancel" : "Скасувати",
    "Delete" : "Вилучити",
    "The configuration is invalid" : "Налаштування не дійсне",
    "Active" : "Активно",
    "Save" : "Зберегти",
    "Available flows" : "Процеси",
    "For details on how to write your own flow, check out the development documentation." : "Перегляньте документацію для розробника, щоби дізнатися, як додати власні процеси.",
    "No flows installed" : "Відсутні процеси",
    "Ask your administrator to install new flows." : "Зверніться до адміністратора щодо встановлення нових процесів.",
    "More flows" : "Більше процесів",
    "Browse the App Store" : "Перейти до каталогу застосунків",
    "Show less" : "Показувати менше",
    "Show more" : "Показати більше",
    "Configured flows" : "Налаштовані процеси",
    "Your flows" : "Ваші процеси",
    "No flows configured" : "Процеси не налаштовано",
    "matches" : "містить",
    "does not match" : "не містить",
    "is" : "є",
    "is not" : "не",
    "File name" : "Ім'я файлу",
    "File MIME type" : "Тип MIME файлу",
    "File size (upload)" : "Розмір файлу (завантаження)",
    "less" : "менше",
    "less or equals" : "менше або дорівнює",
    "greater or equals" : "більше або дорівнює",
    "greater" : "більше",
    "Request remote address" : "Запит віддаленої адреси",
    "matches IPv4" : "відповідає IPv4",
    "does not match IPv4" : "не відповідає IPv4",
    "matches IPv6" : "відповідає IPv6",
    "does not match IPv6" : "не відповідає IPv6",
    "File system tag" : "Мітка файлової системи",
    "is tagged with" : "позначено міткою",
    "is not tagged with" : "не позначено мітками",
    "Request URL" : "URL запиту",
    "Request time" : "Час запиту",
    "between" : "між",
    "not between" : "не між",
    "Request user agent" : "Запит агента користувача",
    "is member of" : "є учасником",
    "is not member of" : "не є учасником",
    "User group membership" : "Участь користувача в групі"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
